==> xpi-ghostery-2.8.3.tbz: lib/xpi/firefox@ghostery.com/defaults/preferences/defaults.js <==
pref('extensions.ghostery.showBubble', true);
pref('extensions.ghostery.showSources', false);
pref('extensions.ghostery.autoDismissBubble', true);
pref('extensions.ghostery.bubbleTimeout', 15);
pref('extensions.ghostery.showBugCount', true);
pref('extensions.ghostery.shareData', false);
pref('extensions.ghostery.censusURL', 'http://l.ghostery.com/api/census');
pref('extensions.ghostery.blockingMode', -1);
pref('extensions.ghostery.enableCleanup', false);
pref('extensions.ghostery.cookieProtect', false);
pref('extensions.ghostery.autoUpdateBugs', true);
pref('extensions.ghostery.lastBugUpdate', '2012_2_10');
pref('extensions.ghostery.selectedBugsUpdated', '');
pref('extensions.ghostery.reloadComponent', false);
pref('extensions.ghostery.reloadList', false);
pref('extensions.ghostery.whitelist', '');
pref('extensions.ghostery.reloadWhiteList', false);
pref('extensions.ghostery.blockingLog', '');
pref('extensions.ghostery.bubbleLocation', 'top-right');
pref('extensions.ghostery.privateBrowsing', false);
pref('extensions.ghostery.tutorial', false);
pref('extensions.ghostery.toolbarButton', false);

/* adding performance options */
pref("extensions.ghostery.blockImage", true);
pref("extensions.ghostery.blockFrame", true);
pref("extensions.ghostery.blockObject", true);
pref("extensions.ghostery.preventRedirect", true);

/* adding update behaviour options */
pref("extensions.ghostery.updateBlockBehaviour", false);
pref("extensions.ghostery.updateNotification", false);
pref("extensions.ghostery.updateLatestBugEntries", '');
pref("extensions.ghostery.updateLatestCookieEntries", '');

/* new blocking on/off toggle */
pref("extensions.ghostery.paused", false);

/* new panel toggle */
pref("extensions.ghostery.panelNew", true);

/* click2play toggle */
pref("extensions.ghostery.showClick2Play", true);
pref("extensions.ghostery.showClick2PlayButton", true);

/* check for update */
pref("extensions.ghostery.allVersion", '');

==> xpi-ghostery-2.9.3.tbz: lib/xpi/firefox@ghostery.com/defaults/preferences/defaults.js <==
pref('extensions.ghostery.showBubble', true);
pref('extensions.ghostery.expandSources', false);
pref('extensions.ghostery.autoDismissBubble', true);
pref('extensions.ghostery.bubbleTimeout', 15);
pref('extensions.ghostery.showBugCount', true);
pref('extensions.ghostery.shareData', false);
pref('extensions.ghostery.censusURL', 'https://l.ghostery.com/api/census');
pref('extensions.ghostery.blockingMode', -1);
pref('extensions.ghostery.enableCleanup', false);
pref('extensions.ghostery.cookieProtect', false);
pref('extensions.ghostery.autoUpdateBugs', true);
pref('extensions.ghostery.lastBugUpdate', '2012_2_10');
pref('extensions.ghostery.selectedBugsUpdated', '');
pref('extensions.ghostery.reloadComponent', false);
pref('extensions.ghostery.reloadList', false);
pref('extensions.ghostery.whitelist', '');
pref('extensions.ghostery.reloadWhiteList', false);
pref('extensions.ghostery.blockingLog', '');
pref('extensions.ghostery.bubbleLocation', 'top-right');
pref('extensions.ghostery.privateBrowsing', false);
pref('extensions.ghostery.tutorial', false);
pref('extensions.ghostery.toolbarButton', false);

/* adding performance options */
pref("extensions.ghostery.blockImage", true);
pref("extensions.ghostery.blockFrame", true);
pref("extensions.ghostery.blockObject", true);
pref("extensions.ghostery.preventRedirect", true);

/* adding update behaviour options */
pref("extensions.ghostery.updateBlockBehaviour", false);
pref("extensions.ghostery.updateNotification", false);
pref("extensions.ghostery.updateLatestBugEntries", '');
pref("extensions.ghostery.updateLatestCookieEntries", '');

/* new blocking on/off toggle */
pref("extensions.ghostery.paused", false);

/* new panel toggle */
pref("extensions.ghostery.panelNew", true);
pref('extensions.ghostery.lastNotificationNag', '0');

/* click2play toggle */
pref("extensions.ghostery.showClick2Play", true);
pref("extensions.ghostery.showClick2PlayButton", true);

/* check for update */
pref("extensions.ghostery.allVersion", '');

pref("extensions.ghostery.userSiteSelections", '');
pref("extensions.ghostery.showTutorial", true);
